@@ -44,7 +44,7 @@ default_args = [
 
 import site
 
-DOWNLOADS_FOLDER = Path(site.getsitepackages()[1]) /'chromium_binary_lambda'/ 'local-chromium'
+DOWNLOADS_FOLDER = Path(site.getsitepackages()[1]) /'chromium_binary_lambda-local-chromium'
 DOWNLOAD_HOST = 'https://storage.googleapis.com'
 BASE_URL = f'{DOWNLOAD_HOST}/chromium-browser-snapshots'
 
@@ -155,7 +155,6 @@ def extract_zip(data: BytesIO, path: Path) -> None:
 
 def download_chromium() -> None:
     """Download and extract chromium."""
-    # extract_zip(download_zip(get_url()), DOWNLOADS_FOLDER / REVISION)
     extract_zip(download_zip(get_url()), DOWNLOADS_FOLDER)
 
 
